// posedge detectors for reset and enter

module prep_inputs (clk, reset_in, reset_out, enter_in, enter_out);
input clk, reset_in, enter_in;
output     reset_out, enter_out;

reg[2:0] r1, r2;

always @ (posedge clk)
begin
	r1 <= {r1[1:0], reset_in};
	r2 <= {r2[1:0], enter_in};
end

assign reset_out = ~r1[2] & r1[1] & r1[0];
assign enter_out = ~r2[2] & r2[1] & r2[0];

endmodule


// Pinouts for 8 segment LED displays
//Pin   
//29	LED_CR3	NumLED_L
//35	LED_CR3	NumLED_L
//36	LED_CR3	NumLED_L
//38	LED_CR3	NumLED_L
//39	LED_CR3	NumLED_L
//40	LED_CR3	NumLED_L
//44	LED_CR3	NumLED_L
//37	LED_CR3	DecPtLED_L

//45	LED_CR4	NumLED_R        e
//46	LED_CR4	NumLED_R        d
//47	LED_CR4	NumLED_R        c
//48	LED_CR4	NumLED_R        b
//49	LED_CR4	NumLED_R        a
//50	LED_CR4	NumLED_R        f
//51	LED_CR4	NumLED_R        g
//41	LED_CR4	DecPtLED_R

//  the layout of 7 segment display:
//
//       ---a---
//       |     |
//       f     b
//       |     |
//       ---g---
//       |     |
//       e     c
//       |     |
//       ---d---

//   NOTE: the out is 7 bit [6:0] output with this layout
//         { g, f, a, b, c, d, e }
//         and all signals are "asserted low"

//  NOTE: this module takes two inputs:
//    in - a four-bit value to be displayed

module bin2LED (in, out_final);

input [3:0] in;
output [6:0] out_final;
reg [6:0] out;

always@(in)
	case (in)
	                    ///gfedcba
		4'b0000 : out <= 7'b1000000;
		4'b0001 : out <= 7'b1111001;
		4'b0010 : out <= 7'b0100100;
		4'b0011 : out <= 7'b0110000;
		4'b0100 : out <= 7'b0011001;
		4'b0101 : out <= 7'b0010010;
		4'b0110 : out <= 7'b0000010;
		4'b0111 : out <= 7'b1111000;

//       ---a---
//       |     |
//       f     b
//       |     |
//       ---g---
//       |     |
//       e     c
//       |     |
//       ---d---
	                    ///gfedcba		
		4'b1000 : out <= 7'b0000000;
		4'b1001 : out <= 7'b0010000;
		4'b1010 : out <= 7'b0001000;
		4'b1011 : out <= 7'b0000011;
		4'b1100 : out <= 7'b1000110;
		4'b1101 : out <= 7'b0100001;
		4'b1110 : out <= 7'b0000110;
		4'b1111 : out <= 7'b0001110;

		default : out <= 7'b0;
	endcase

 	assign out_final = ~out; // invert because it's asserted low

endmodule

